@@ -26,3 +26,6 @@
 
 /* AIDE compile options */
 #undef AIDECOMPILEOPTIONS
+
+#undef HAVE_readdir
+#undef HAVE_readdir_r
