@@ -349,7 +349,9 @@ int main(int argc,char**argv)
 	exit(IO_ERROR);
       }
     }
-  }else if(conf->action&DO_COMPARE){
+  }
+  
+  if(conf->action&DO_COMPARE){
     if(db_init(1)==RETFAIL)
       exit(IO_ERROR);
     compare_db(newlst);
