@@ -31,8 +31,10 @@
 
 
 #include <stdio.h>
+#include <stdlib.h>
 #include "config.h"
 #include "base64.h"
+#include "error.h"
 
 char tob64[] = 
 "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
