@@ -17,7 +17,9 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include <stdlib.h>
 #include <string.h>
+#include "base64.h"
 #include "error.h"
 #include "db_config.h"
 #include "aide.h"
@@ -223,7 +225,7 @@ void free_db_line(db_line* dl)
 
 }
 
-int compare_db(list* new)
+void compare_db(list* new)
 {
   db_line* old=NULL;
   list* l=new;
@@ -299,7 +301,7 @@ int compare_db(list* new)
       }
     }
     
-    if(conf->verbose_level>5){
+    if((conf->verbose_level>5)&&(nchg!=0)){
       error(20,"Detailed information about changes:\n");
       for(r=changedold,l=changednew;r;r=r->next,l=l->next){
 	print_dbline_changes((db_line*)r->data,(db_line*)l->data);
