@@ -130,8 +130,13 @@ char** db_readline_file(db_config* conf){
 	break;
       }
 
+      case url_fd: {
+	error(0,"FD-database must have one db_spec spesification\n");
+	break;
+      }
+
       default : {
-	error(0,"Unknown or unsupported db in type.\n");
+	error(0,"db_readline_file():Unknown or unsupported db in type.\n");
 	
 	break;
       }
