@@ -18,12 +18,15 @@
  */
  
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <errno.h>
-#include "db_config.h"
-#include "list.h"
-#include "do_md.h"
+
 #include "cipher.h"
+#include "db_config.h"
+#include "do_md.h"
+#include "error.h"
+#include "list.h"
 
 list* do_md(list* file_lst)
 {
@@ -33,7 +36,6 @@ list* do_md(list* file_lst)
   FILE* fh=NULL;
   void* buf=NULL;
   size_t bread;
-  byte* mdres=NULL;
 
   mdh=md_open(0,0);
   
