@@ -17,11 +17,11 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
-#include <stdlib.h>
-#include "error.h"
 
+#include "error.h"
 #include "db_config.h"
 #include "util.h"
 
@@ -35,6 +35,18 @@ static const int url_value[] = {
 
 const int url_ntypes=sizeof(url_value)/sizeof(int);
 
+int cmpurl(url_t* u1,url_t* u2)
+{
+  if(u1->type!= u2->type){
+    return RETFAIL;
+  };
+  if(strcmp(u1->value,u2->value)!=0){
+    return RETFAIL;
+  }
+
+  return RETOK;
+};
+
 url_t* parse_url(char* val)
 {
   url_t* u=NULL;
